@@ -18,16 +18,20 @@
 
 #ifdef __MODULE__
 #include "gnome-mud.h"
-#include "modules.h"
+#include "modules-structures.h"
 
 /*
  * Runnable functions from inside the module.
  */
 extern void     plugin_popup_message          (gchar *message                       );
-extern void     plugin_add_connection_text    (CONNECTION_DATA *c, gchar *t, gint ct);
-extern gboolean plugin_register_menu          (gint h, gchar *name, gchar *function );
-extern gboolean plugin_register_data_incoming (gint h, gchar *function              );
-extern gboolean plugin_register_data_outgoing (gint h, gchar *function              );
-extern void	plugin_connection_send        (gchar *text                          );
+extern void plugin_add_connection_text(gchar *message, gint color, MudConnectionView *view);
+extern gboolean plugin_register_menu          (GModule *h, gchar *name, gchar *function );
+extern gboolean plugin_register_data_incoming (GModule *h, gchar *function              );
+extern gboolean plugin_register_data_outgoing (GModule *h, gchar *function              );
+extern void plugin_connection_send	      (gchar *text,  MudConnectionView *view);
+
+/* Hack for the moment, will refactor with plugin rewrite - lh */
+extern gboolean PluginGag;
+extern void plugin_gag_flag(void);
 
 #endif /* __MODULE__ */
